# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import getgauge.messages.spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api.proto',
  package='gauge.messages',
  syntax='proto3',
  serialized_pb=_b('\n\tapi.proto\x12\x0egauge.messages\x1a\nspec.proto\"\x17\n\x15GetProjectRootRequest\"-\n\x16GetProjectRootResponse\x12\x13\n\x0bprojectRoot\x18\x01 \x01(\t\"\x1c\n\x1aGetInstallationRootRequest\"7\n\x1bGetInstallationRootResponse\x12\x18\n\x10installationRoot\x18\x01 \x01(\t\"\x14\n\x12GetAllStepsRequest\"G\n\x13GetAllStepsResponse\x12\x30\n\x08\x61llSteps\x18\x01 \x03(\x0b\x32\x1e.gauge.messages.ProtoStepValue\"\x1d\n\x0cSpecsRequest\x12\r\n\x05specs\x18\x01 \x03(\t\"\xad\x01\n\rSpecsResponse\x12\x39\n\x07\x64\x65tails\x18\x01 \x03(\x0b\x32(.gauge.messages.SpecsResponse.SpecDetail\x1a\x61\n\nSpecDetail\x12\'\n\x04spec\x18\x01 \x01(\x0b\x32\x19.gauge.messages.ProtoSpec\x12*\n\x0bparseErrors\x18\x02 \x03(\x0b\x32\x15.gauge.messages.Error\"\x17\n\x15GetAllConceptsRequest\"G\n\x16GetAllConceptsResponse\x12-\n\x08\x63oncepts\x18\x01 \x03(\x0b\x32\x1b.gauge.messages.ConceptInfo\"f\n\x0b\x43onceptInfo\x12\x31\n\tstepValue\x18\x01 \x01(\x0b\x32\x1e.gauge.messages.ProtoStepValue\x12\x10\n\x08\x66ilepath\x18\x02 \x01(\t\x12\x12\n\nlineNumber\x18\x03 \x01(\x05\"?\n\x13GetStepValueRequest\x12\x10\n\x08stepText\x18\x01 \x01(\t\x12\x16\n\x0ehasInlineTable\x18\x02 \x01(\x08\"I\n\x14GetStepValueResponse\x12\x31\n\tstepValue\x18\x01 \x01(\x0b\x32\x1e.gauge.messages.ProtoStepValue\"3\n\x1fGetLanguagePluginLibPathRequest\x12\x10\n\x08language\x18\x01 \x01(\t\"0\n GetLanguagePluginLibPathResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x1e\n\rErrorResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"=\n\x19PerformRefactoringRequest\x12\x0f\n\x07oldStep\x18\x01 \x01(\t\x12\x0f\n\x07newStep\x18\x02 \x01(\t\"S\n\x1aPerformRefactoringResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06\x65rrors\x18\x02 \x03(\t\x12\x14\n\x0c\x66ilesChanged\x18\x03 \x03(\t\"\xd1\x01\n\x15\x45xtractConceptRequest\x12)\n\x0b\x63onceptName\x18\x01 \x01(\x0b\x32\x14.gauge.messages.step\x12#\n\x05steps\x18\x02 \x03(\x0b\x32\x14.gauge.messages.step\x12\x1b\n\x13\x63hangeAcrossProject\x18\x03 \x01(\x08\x12\x17\n\x0f\x63onceptFileName\x18\x04 \x01(\t\x12\x32\n\x10selectedTextInfo\x18\x05 \x01(\x0b\x32\x18.gauge.messages.textInfo\"G\n\x08textInfo\x12\x10\n\x08\x66ileName\x18\x01 \x01(\t\x12\x16\n\x0estartingLineNo\x18\x02 \x01(\x05\x12\x11\n\tendLineNo\x18\x03 \x01(\x05\";\n\x04step\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05table\x18\x02 \x01(\t\x12\x16\n\x0eparamTableName\x18\x03 \x01(\t\"P\n\x16\x45xtractConceptResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x14\n\x0c\x66ilesChanged\x18\x03 \x03(\t\"#\n\x12\x46ormatSpecsRequest\x12\r\n\x05specs\x18\x01 \x03(\t\"7\n\x13\x46ormatSpecsResponse\x12\x0e\n\x06\x65rrors\x18\x01 \x03(\t\x12\x10\n\x08warnings\x18\x02 \x03(\t\"\x1f\n\x1dUnsupportedApiMessageResponse\"\xa9\x11\n\nAPIMessage\x12>\n\x0bmessageType\x18\x01 \x01(\x0e\x32).gauge.messages.APIMessage.APIMessageType\x12\x11\n\tmessageId\x18\x02 \x01(\x03\x12\x41\n\x12projectRootRequest\x18\x03 \x01(\x0b\x32%.gauge.messages.GetProjectRootRequest\x12\x43\n\x13projectRootResponse\x18\x04 \x01(\x0b\x32&.gauge.messages.GetProjectRootResponse\x12K\n\x17installationRootRequest\x18\x05 \x01(\x0b\x32*.gauge.messages.GetInstallationRootRequest\x12M\n\x18installationRootResponse\x18\x06 \x01(\x0b\x32+.gauge.messages.GetInstallationRootResponse\x12;\n\x0f\x61llStepsRequest\x18\x07 \x01(\x0b\x32\".gauge.messages.GetAllStepsRequest\x12=\n\x10\x61llStepsResponse\x18\x08 \x01(\x0b\x32#.gauge.messages.GetAllStepsResponse\x12\x32\n\x0cspecsRequest\x18\t \x01(\x0b\x32\x1c.gauge.messages.SpecsRequest\x12\x34\n\rspecsResponse\x18\n \x01(\x0b\x32\x1d.gauge.messages.SpecsResponse\x12=\n\x10stepValueRequest\x18\x0b \x01(\x0b\x32#.gauge.messages.GetStepValueRequest\x12?\n\x11stepValueResponse\x18\x0c \x01(\x0b\x32$.gauge.messages.GetStepValueResponse\x12G\n\x0elibPathRequest\x18\r \x01(\x0b\x32/.gauge.messages.GetLanguagePluginLibPathRequest\x12I\n\x0flibPathResponse\x18\x0e \x01(\x0b\x32\x30.gauge.messages.GetLanguagePluginLibPathResponse\x12,\n\x05\x65rror\x18\x0f \x01(\x0b\x32\x1d.gauge.messages.ErrorResponse\x12\x41\n\x12\x61llConceptsRequest\x18\x10 \x01(\x0b\x32%.gauge.messages.GetAllConceptsRequest\x12\x43\n\x13\x61llConceptsResponse\x18\x11 \x01(\x0b\x32&.gauge.messages.GetAllConceptsResponse\x12L\n\x19performRefactoringRequest\x18\x12 \x01(\x0b\x32).gauge.messages.PerformRefactoringRequest\x12N\n\x1aperformRefactoringResponse\x18\x13 \x01(\x0b\x32*.gauge.messages.PerformRefactoringResponse\x12\x44\n\x15\x65xtractConceptRequest\x18\x14 \x01(\x0b\x32%.gauge.messages.ExtractConceptRequest\x12\x46\n\x16\x65xtractConceptResponse\x18\x15 \x01(\x0b\x32&.gauge.messages.ExtractConceptResponse\x12>\n\x12\x66ormatSpecsRequest\x18\x16 \x01(\x0b\x32\".gauge.messages.FormatSpecsRequest\x12@\n\x13\x66ormatSpecsResponse\x18\x17 \x01(\x0b\x32#.gauge.messages.FormatSpecsResponse\x12T\n\x1dunsupportedApiMessageResponse\x18\x18 \x01(\x0b\x32-.gauge.messages.UnsupportedApiMessageResponse\"\xef\x04\n\x0e\x41PIMessageType\x12\x19\n\x15GetProjectRootRequest\x10\x00\x12\x1a\n\x16GetProjectRootResponse\x10\x01\x12\x1e\n\x1aGetInstallationRootRequest\x10\x02\x12\x1f\n\x1bGetInstallationRootResponse\x10\x03\x12\x16\n\x12GetAllStepsRequest\x10\x04\x12\x16\n\x12GetAllStepResponse\x10\x05\x12\x10\n\x0cSpecsRequest\x10\x06\x12\x11\n\rSpecsResponse\x10\x07\x12\x17\n\x13GetStepValueRequest\x10\x08\x12\x18\n\x14GetStepValueResponse\x10\t\x12#\n\x1fGetLanguagePluginLibPathRequest\x10\n\x12$\n GetLanguagePluginLibPathResponse\x10\x0b\x12\x11\n\rErrorResponse\x10\x0c\x12\x19\n\x15GetAllConceptsRequest\x10\r\x12\x1a\n\x16GetAllConceptsResponse\x10\x0e\x12\x1d\n\x19PerformRefactoringRequest\x10\x0f\x12\x1e\n\x1aPerformRefactoringResponse\x10\x10\x12\x19\n\x15\x45xtractConceptRequest\x10\x11\x12\x1a\n\x16\x45xtractConceptResponse\x10\x12\x12\x16\n\x12\x46ormatSpecsRequest\x10\x13\x12\x17\n\x13\x46ormatSpecsResponse\x10\x14\x12!\n\x1dUnsupportedApiMessageResponse\x10\x15\x42)\n\x16\x63om.thoughtworks.gauge\xaa\x02\x0eGauge.Messagesb\x06proto3')
  ,
  dependencies=[spec__pb2.DESCRIPTOR,])



_APIMESSAGE_APIMESSAGETYPE = _descriptor.EnumDescriptor(
  name='APIMessageType',
  full_name='gauge.messages.APIMessage.APIMessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GetProjectRootRequest', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetProjectRootResponse', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetInstallationRootRequest', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetInstallationRootResponse', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetAllStepsRequest', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetAllStepResponse', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SpecsRequest', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SpecsResponse', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetStepValueRequest', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetStepValueResponse', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetLanguagePluginLibPathRequest', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetLanguagePluginLibPathResponse', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ErrorResponse', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetAllConceptsRequest', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetAllConceptsResponse', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PerformRefactoringRequest', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PerformRefactoringResponse', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExtractConceptRequest', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExtractConceptResponse', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FormatSpecsRequest', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FormatSpecsResponse', index=20, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnsupportedApiMessageResponse', index=21, number=21,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3277,
  serialized_end=3900,
)
_sym_db.RegisterEnumDescriptor(_APIMESSAGE_APIMESSAGETYPE)


_GETPROJECTROOTREQUEST = _descriptor.Descriptor(
  name='GetProjectRootRequest',
  full_name='gauge.messages.GetProjectRootRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=64,
)


_GETPROJECTROOTRESPONSE = _descriptor.Descriptor(
  name='GetProjectRootResponse',
  full_name='gauge.messages.GetProjectRootResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projectRoot', full_name='gauge.messages.GetProjectRootResponse.projectRoot', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=111,
)


_GETINSTALLATIONROOTREQUEST = _descriptor.Descriptor(
  name='GetInstallationRootRequest',
  full_name='gauge.messages.GetInstallationRootRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=141,
)


_GETINSTALLATIONROOTRESPONSE = _descriptor.Descriptor(
  name='GetInstallationRootResponse',
  full_name='gauge.messages.GetInstallationRootResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='installationRoot', full_name='gauge.messages.GetInstallationRootResponse.installationRoot', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=198,
)


_GETALLSTEPSREQUEST = _descriptor.Descriptor(
  name='GetAllStepsRequest',
  full_name='gauge.messages.GetAllStepsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=220,
)


_GETALLSTEPSRESPONSE = _descriptor.Descriptor(
  name='GetAllStepsResponse',
  full_name='gauge.messages.GetAllStepsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='allSteps', full_name='gauge.messages.GetAllStepsResponse.allSteps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=293,
)


_SPECSREQUEST = _descriptor.Descriptor(
  name='SpecsRequest',
  full_name='gauge.messages.SpecsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='specs', full_name='gauge.messages.SpecsRequest.specs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=324,
)


_SPECSRESPONSE_SPECDETAIL = _descriptor.Descriptor(
  name='SpecDetail',
  full_name='gauge.messages.SpecsResponse.SpecDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec', full_name='gauge.messages.SpecsResponse.SpecDetail.spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parseErrors', full_name='gauge.messages.SpecsResponse.SpecDetail.parseErrors', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=500,
)

_SPECSRESPONSE = _descriptor.Descriptor(
  name='SpecsResponse',
  full_name='gauge.messages.SpecsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='details', full_name='gauge.messages.SpecsResponse.details', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPECSRESPONSE_SPECDETAIL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=500,
)


_GETALLCONCEPTSREQUEST = _descriptor.Descriptor(
  name='GetAllConceptsRequest',
  full_name='gauge.messages.GetAllConceptsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=525,
)


_GETALLCONCEPTSRESPONSE = _descriptor.Descriptor(
  name='GetAllConceptsResponse',
  full_name='gauge.messages.GetAllConceptsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concepts', full_name='gauge.messages.GetAllConceptsResponse.concepts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=598,
)


_CONCEPTINFO = _descriptor.Descriptor(
  name='ConceptInfo',
  full_name='gauge.messages.ConceptInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepValue', full_name='gauge.messages.ConceptInfo.stepValue', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filepath', full_name='gauge.messages.ConceptInfo.filepath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lineNumber', full_name='gauge.messages.ConceptInfo.lineNumber', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=702,
)


_GETSTEPVALUEREQUEST = _descriptor.Descriptor(
  name='GetStepValueRequest',
  full_name='gauge.messages.GetStepValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepText', full_name='gauge.messages.GetStepValueRequest.stepText', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasInlineTable', full_name='gauge.messages.GetStepValueRequest.hasInlineTable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=767,
)


_GETSTEPVALUERESPONSE = _descriptor.Descriptor(
  name='GetStepValueResponse',
  full_name='gauge.messages.GetStepValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepValue', full_name='gauge.messages.GetStepValueResponse.stepValue', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=842,
)


_GETLANGUAGEPLUGINLIBPATHREQUEST = _descriptor.Descriptor(
  name='GetLanguagePluginLibPathRequest',
  full_name='gauge.messages.GetLanguagePluginLibPathRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='gauge.messages.GetLanguagePluginLibPathRequest.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=895,
)


_GETLANGUAGEPLUGINLIBPATHRESPONSE = _descriptor.Descriptor(
  name='GetLanguagePluginLibPathResponse',
  full_name='gauge.messages.GetLanguagePluginLibPathResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='gauge.messages.GetLanguagePluginLibPathResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=897,
  serialized_end=945,
)


_ERRORRESPONSE = _descriptor.Descriptor(
  name='ErrorResponse',
  full_name='gauge.messages.ErrorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='gauge.messages.ErrorResponse.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=947,
  serialized_end=977,
)


_PERFORMREFACTORINGREQUEST = _descriptor.Descriptor(
  name='PerformRefactoringRequest',
  full_name='gauge.messages.PerformRefactoringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='oldStep', full_name='gauge.messages.PerformRefactoringRequest.oldStep', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newStep', full_name='gauge.messages.PerformRefactoringRequest.newStep', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=979,
  serialized_end=1040,
)


_PERFORMREFACTORINGRESPONSE = _descriptor.Descriptor(
  name='PerformRefactoringResponse',
  full_name='gauge.messages.PerformRefactoringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='gauge.messages.PerformRefactoringResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errors', full_name='gauge.messages.PerformRefactoringResponse.errors', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filesChanged', full_name='gauge.messages.PerformRefactoringResponse.filesChanged', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1125,
)


_EXTRACTCONCEPTREQUEST = _descriptor.Descriptor(
  name='ExtractConceptRequest',
  full_name='gauge.messages.ExtractConceptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conceptName', full_name='gauge.messages.ExtractConceptRequest.conceptName', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steps', full_name='gauge.messages.ExtractConceptRequest.steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changeAcrossProject', full_name='gauge.messages.ExtractConceptRequest.changeAcrossProject', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conceptFileName', full_name='gauge.messages.ExtractConceptRequest.conceptFileName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectedTextInfo', full_name='gauge.messages.ExtractConceptRequest.selectedTextInfo', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1337,
)


_TEXTINFO = _descriptor.Descriptor(
  name='textInfo',
  full_name='gauge.messages.textInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileName', full_name='gauge.messages.textInfo.fileName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startingLineNo', full_name='gauge.messages.textInfo.startingLineNo', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endLineNo', full_name='gauge.messages.textInfo.endLineNo', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1339,
  serialized_end=1410,
)


_STEP = _descriptor.Descriptor(
  name='step',
  full_name='gauge.messages.step',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gauge.messages.step.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='gauge.messages.step.table', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paramTableName', full_name='gauge.messages.step.paramTableName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1412,
  serialized_end=1471,
)


_EXTRACTCONCEPTRESPONSE = _descriptor.Descriptor(
  name='ExtractConceptResponse',
  full_name='gauge.messages.ExtractConceptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='gauge.messages.ExtractConceptResponse.isSuccess', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='gauge.messages.ExtractConceptResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filesChanged', full_name='gauge.messages.ExtractConceptResponse.filesChanged', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1553,
)


_FORMATSPECSREQUEST = _descriptor.Descriptor(
  name='FormatSpecsRequest',
  full_name='gauge.messages.FormatSpecsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='specs', full_name='gauge.messages.FormatSpecsRequest.specs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1555,
  serialized_end=1590,
)


_FORMATSPECSRESPONSE = _descriptor.Descriptor(
  name='FormatSpecsResponse',
  full_name='gauge.messages.FormatSpecsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='gauge.messages.FormatSpecsResponse.errors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warnings', full_name='gauge.messages.FormatSpecsResponse.warnings', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1592,
  serialized_end=1647,
)


_UNSUPPORTEDAPIMESSAGERESPONSE = _descriptor.Descriptor(
  name='UnsupportedApiMessageResponse',
  full_name='gauge.messages.UnsupportedApiMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1649,
  serialized_end=1680,
)


_APIMESSAGE = _descriptor.Descriptor(
  name='APIMessage',
  full_name='gauge.messages.APIMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messageType', full_name='gauge.messages.APIMessage.messageType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messageId', full_name='gauge.messages.APIMessage.messageId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='projectRootRequest', full_name='gauge.messages.APIMessage.projectRootRequest', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='projectRootResponse', full_name='gauge.messages.APIMessage.projectRootResponse', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='installationRootRequest', full_name='gauge.messages.APIMessage.installationRootRequest', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='installationRootResponse', full_name='gauge.messages.APIMessage.installationRootResponse', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allStepsRequest', full_name='gauge.messages.APIMessage.allStepsRequest', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allStepsResponse', full_name='gauge.messages.APIMessage.allStepsResponse', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specsRequest', full_name='gauge.messages.APIMessage.specsRequest', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specsResponse', full_name='gauge.messages.APIMessage.specsResponse', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepValueRequest', full_name='gauge.messages.APIMessage.stepValueRequest', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepValueResponse', full_name='gauge.messages.APIMessage.stepValueResponse', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='libPathRequest', full_name='gauge.messages.APIMessage.libPathRequest', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='libPathResponse', full_name='gauge.messages.APIMessage.libPathResponse', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='gauge.messages.APIMessage.error', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allConceptsRequest', full_name='gauge.messages.APIMessage.allConceptsRequest', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allConceptsResponse', full_name='gauge.messages.APIMessage.allConceptsResponse', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performRefactoringRequest', full_name='gauge.messages.APIMessage.performRefactoringRequest', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performRefactoringResponse', full_name='gauge.messages.APIMessage.performRefactoringResponse', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extractConceptRequest', full_name='gauge.messages.APIMessage.extractConceptRequest', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extractConceptResponse', full_name='gauge.messages.APIMessage.extractConceptResponse', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatSpecsRequest', full_name='gauge.messages.APIMessage.formatSpecsRequest', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatSpecsResponse', full_name='gauge.messages.APIMessage.formatSpecsResponse', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsupportedApiMessageResponse', full_name='gauge.messages.APIMessage.unsupportedApiMessageResponse', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _APIMESSAGE_APIMESSAGETYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=3900,
)

_GETALLSTEPSRESPONSE.fields_by_name['allSteps'].message_type = spec__pb2._PROTOSTEPVALUE
_SPECSRESPONSE_SPECDETAIL.fields_by_name['spec'].message_type = spec__pb2._PROTOSPEC
_SPECSRESPONSE_SPECDETAIL.fields_by_name['parseErrors'].message_type = spec__pb2._ERROR
_SPECSRESPONSE_SPECDETAIL.containing_type = _SPECSRESPONSE
_SPECSRESPONSE.fields_by_name['details'].message_type = _SPECSRESPONSE_SPECDETAIL
_GETALLCONCEPTSRESPONSE.fields_by_name['concepts'].message_type = _CONCEPTINFO
_CONCEPTINFO.fields_by_name['stepValue'].message_type = spec__pb2._PROTOSTEPVALUE
_GETSTEPVALUERESPONSE.fields_by_name['stepValue'].message_type = spec__pb2._PROTOSTEPVALUE
_EXTRACTCONCEPTREQUEST.fields_by_name['conceptName'].message_type = _STEP
_EXTRACTCONCEPTREQUEST.fields_by_name['steps'].message_type = _STEP
_EXTRACTCONCEPTREQUEST.fields_by_name['selectedTextInfo'].message_type = _TEXTINFO
_APIMESSAGE.fields_by_name['messageType'].enum_type = _APIMESSAGE_APIMESSAGETYPE
_APIMESSAGE.fields_by_name['projectRootRequest'].message_type = _GETPROJECTROOTREQUEST
_APIMESSAGE.fields_by_name['projectRootResponse'].message_type = _GETPROJECTROOTRESPONSE
_APIMESSAGE.fields_by_name['installationRootRequest'].message_type = _GETINSTALLATIONROOTREQUEST
_APIMESSAGE.fields_by_name['installationRootResponse'].message_type = _GETINSTALLATIONROOTRESPONSE
_APIMESSAGE.fields_by_name['allStepsRequest'].message_type = _GETALLSTEPSREQUEST
_APIMESSAGE.fields_by_name['allStepsResponse'].message_type = _GETALLSTEPSRESPONSE
_APIMESSAGE.fields_by_name['specsRequest'].message_type = _SPECSREQUEST
_APIMESSAGE.fields_by_name['specsResponse'].message_type = _SPECSRESPONSE
_APIMESSAGE.fields_by_name['stepValueRequest'].message_type = _GETSTEPVALUEREQUEST
_APIMESSAGE.fields_by_name['stepValueResponse'].message_type = _GETSTEPVALUERESPONSE
_APIMESSAGE.fields_by_name['libPathRequest'].message_type = _GETLANGUAGEPLUGINLIBPATHREQUEST
_APIMESSAGE.fields_by_name['libPathResponse'].message_type = _GETLANGUAGEPLUGINLIBPATHRESPONSE
_APIMESSAGE.fields_by_name['error'].message_type = _ERRORRESPONSE
_APIMESSAGE.fields_by_name['allConceptsRequest'].message_type = _GETALLCONCEPTSREQUEST
_APIMESSAGE.fields_by_name['allConceptsResponse'].message_type = _GETALLCONCEPTSRESPONSE
_APIMESSAGE.fields_by_name['performRefactoringRequest'].message_type = _PERFORMREFACTORINGREQUEST
_APIMESSAGE.fields_by_name['performRefactoringResponse'].message_type = _PERFORMREFACTORINGRESPONSE
_APIMESSAGE.fields_by_name['extractConceptRequest'].message_type = _EXTRACTCONCEPTREQUEST
_APIMESSAGE.fields_by_name['extractConceptResponse'].message_type = _EXTRACTCONCEPTRESPONSE
_APIMESSAGE.fields_by_name['formatSpecsRequest'].message_type = _FORMATSPECSREQUEST
_APIMESSAGE.fields_by_name['formatSpecsResponse'].message_type = _FORMATSPECSRESPONSE
_APIMESSAGE.fields_by_name['unsupportedApiMessageResponse'].message_type = _UNSUPPORTEDAPIMESSAGERESPONSE
_APIMESSAGE_APIMESSAGETYPE.containing_type = _APIMESSAGE
DESCRIPTOR.message_types_by_name['GetProjectRootRequest'] = _GETPROJECTROOTREQUEST
DESCRIPTOR.message_types_by_name['GetProjectRootResponse'] = _GETPROJECTROOTRESPONSE
DESCRIPTOR.message_types_by_name['GetInstallationRootRequest'] = _GETINSTALLATIONROOTREQUEST
DESCRIPTOR.message_types_by_name['GetInstallationRootResponse'] = _GETINSTALLATIONROOTRESPONSE
DESCRIPTOR.message_types_by_name['GetAllStepsRequest'] = _GETALLSTEPSREQUEST
DESCRIPTOR.message_types_by_name['GetAllStepsResponse'] = _GETALLSTEPSRESPONSE
DESCRIPTOR.message_types_by_name['SpecsRequest'] = _SPECSREQUEST
DESCRIPTOR.message_types_by_name['SpecsResponse'] = _SPECSRESPONSE
DESCRIPTOR.message_types_by_name['GetAllConceptsRequest'] = _GETALLCONCEPTSREQUEST
DESCRIPTOR.message_types_by_name['GetAllConceptsResponse'] = _GETALLCONCEPTSRESPONSE
DESCRIPTOR.message_types_by_name['ConceptInfo'] = _CONCEPTINFO
DESCRIPTOR.message_types_by_name['GetStepValueRequest'] = _GETSTEPVALUEREQUEST
DESCRIPTOR.message_types_by_name['GetStepValueResponse'] = _GETSTEPVALUERESPONSE
DESCRIPTOR.message_types_by_name['GetLanguagePluginLibPathRequest'] = _GETLANGUAGEPLUGINLIBPATHREQUEST
DESCRIPTOR.message_types_by_name['GetLanguagePluginLibPathResponse'] = _GETLANGUAGEPLUGINLIBPATHRESPONSE
DESCRIPTOR.message_types_by_name['ErrorResponse'] = _ERRORRESPONSE
DESCRIPTOR.message_types_by_name['PerformRefactoringRequest'] = _PERFORMREFACTORINGREQUEST
DESCRIPTOR.message_types_by_name['PerformRefactoringResponse'] = _PERFORMREFACTORINGRESPONSE
DESCRIPTOR.message_types_by_name['ExtractConceptRequest'] = _EXTRACTCONCEPTREQUEST
DESCRIPTOR.message_types_by_name['textInfo'] = _TEXTINFO
DESCRIPTOR.message_types_by_name['step'] = _STEP
DESCRIPTOR.message_types_by_name['ExtractConceptResponse'] = _EXTRACTCONCEPTRESPONSE
DESCRIPTOR.message_types_by_name['FormatSpecsRequest'] = _FORMATSPECSREQUEST
DESCRIPTOR.message_types_by_name['FormatSpecsResponse'] = _FORMATSPECSRESPONSE
DESCRIPTOR.message_types_by_name['UnsupportedApiMessageResponse'] = _UNSUPPORTEDAPIMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['APIMessage'] = _APIMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetProjectRootRequest = _reflection.GeneratedProtocolMessageType('GetProjectRootRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPROJECTROOTREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetProjectRootRequest)
  ))
_sym_db.RegisterMessage(GetProjectRootRequest)

GetProjectRootResponse = _reflection.GeneratedProtocolMessageType('GetProjectRootResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETPROJECTROOTRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetProjectRootResponse)
  ))
_sym_db.RegisterMessage(GetProjectRootResponse)

GetInstallationRootRequest = _reflection.GeneratedProtocolMessageType('GetInstallationRootRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETINSTALLATIONROOTREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetInstallationRootRequest)
  ))
_sym_db.RegisterMessage(GetInstallationRootRequest)

GetInstallationRootResponse = _reflection.GeneratedProtocolMessageType('GetInstallationRootResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETINSTALLATIONROOTRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetInstallationRootResponse)
  ))
_sym_db.RegisterMessage(GetInstallationRootResponse)

GetAllStepsRequest = _reflection.GeneratedProtocolMessageType('GetAllStepsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETALLSTEPSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetAllStepsRequest)
  ))
_sym_db.RegisterMessage(GetAllStepsRequest)

GetAllStepsResponse = _reflection.GeneratedProtocolMessageType('GetAllStepsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETALLSTEPSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetAllStepsResponse)
  ))
_sym_db.RegisterMessage(GetAllStepsResponse)

SpecsRequest = _reflection.GeneratedProtocolMessageType('SpecsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SPECSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.SpecsRequest)
  ))
_sym_db.RegisterMessage(SpecsRequest)

SpecsResponse = _reflection.GeneratedProtocolMessageType('SpecsResponse', (_message.Message,), dict(

  SpecDetail = _reflection.GeneratedProtocolMessageType('SpecDetail', (_message.Message,), dict(
    DESCRIPTOR = _SPECSRESPONSE_SPECDETAIL,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:gauge.messages.SpecsResponse.SpecDetail)
    ))
  ,
  DESCRIPTOR = _SPECSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.SpecsResponse)
  ))
_sym_db.RegisterMessage(SpecsResponse)
_sym_db.RegisterMessage(SpecsResponse.SpecDetail)

GetAllConceptsRequest = _reflection.GeneratedProtocolMessageType('GetAllConceptsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETALLCONCEPTSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetAllConceptsRequest)
  ))
_sym_db.RegisterMessage(GetAllConceptsRequest)

GetAllConceptsResponse = _reflection.GeneratedProtocolMessageType('GetAllConceptsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETALLCONCEPTSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetAllConceptsResponse)
  ))
_sym_db.RegisterMessage(GetAllConceptsResponse)

ConceptInfo = _reflection.GeneratedProtocolMessageType('ConceptInfo', (_message.Message,), dict(
  DESCRIPTOR = _CONCEPTINFO,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ConceptInfo)
  ))
_sym_db.RegisterMessage(ConceptInfo)

GetStepValueRequest = _reflection.GeneratedProtocolMessageType('GetStepValueRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSTEPVALUEREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetStepValueRequest)
  ))
_sym_db.RegisterMessage(GetStepValueRequest)

GetStepValueResponse = _reflection.GeneratedProtocolMessageType('GetStepValueResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSTEPVALUERESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetStepValueResponse)
  ))
_sym_db.RegisterMessage(GetStepValueResponse)

GetLanguagePluginLibPathRequest = _reflection.GeneratedProtocolMessageType('GetLanguagePluginLibPathRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLANGUAGEPLUGINLIBPATHREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetLanguagePluginLibPathRequest)
  ))
_sym_db.RegisterMessage(GetLanguagePluginLibPathRequest)

GetLanguagePluginLibPathResponse = _reflection.GeneratedProtocolMessageType('GetLanguagePluginLibPathResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLANGUAGEPLUGINLIBPATHRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.GetLanguagePluginLibPathResponse)
  ))
_sym_db.RegisterMessage(GetLanguagePluginLibPathResponse)

ErrorResponse = _reflection.GeneratedProtocolMessageType('ErrorResponse', (_message.Message,), dict(
  DESCRIPTOR = _ERRORRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ErrorResponse)
  ))
_sym_db.RegisterMessage(ErrorResponse)

PerformRefactoringRequest = _reflection.GeneratedProtocolMessageType('PerformRefactoringRequest', (_message.Message,), dict(
  DESCRIPTOR = _PERFORMREFACTORINGREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.PerformRefactoringRequest)
  ))
_sym_db.RegisterMessage(PerformRefactoringRequest)

PerformRefactoringResponse = _reflection.GeneratedProtocolMessageType('PerformRefactoringResponse', (_message.Message,), dict(
  DESCRIPTOR = _PERFORMREFACTORINGRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.PerformRefactoringResponse)
  ))
_sym_db.RegisterMessage(PerformRefactoringResponse)

ExtractConceptRequest = _reflection.GeneratedProtocolMessageType('ExtractConceptRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXTRACTCONCEPTREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ExtractConceptRequest)
  ))
_sym_db.RegisterMessage(ExtractConceptRequest)

textInfo = _reflection.GeneratedProtocolMessageType('textInfo', (_message.Message,), dict(
  DESCRIPTOR = _TEXTINFO,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.textInfo)
  ))
_sym_db.RegisterMessage(textInfo)

step = _reflection.GeneratedProtocolMessageType('step', (_message.Message,), dict(
  DESCRIPTOR = _STEP,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.step)
  ))
_sym_db.RegisterMessage(step)

ExtractConceptResponse = _reflection.GeneratedProtocolMessageType('ExtractConceptResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXTRACTCONCEPTRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ExtractConceptResponse)
  ))
_sym_db.RegisterMessage(ExtractConceptResponse)

FormatSpecsRequest = _reflection.GeneratedProtocolMessageType('FormatSpecsRequest', (_message.Message,), dict(
  DESCRIPTOR = _FORMATSPECSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.FormatSpecsRequest)
  ))
_sym_db.RegisterMessage(FormatSpecsRequest)

FormatSpecsResponse = _reflection.GeneratedProtocolMessageType('FormatSpecsResponse', (_message.Message,), dict(
  DESCRIPTOR = _FORMATSPECSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.FormatSpecsResponse)
  ))
_sym_db.RegisterMessage(FormatSpecsResponse)

UnsupportedApiMessageResponse = _reflection.GeneratedProtocolMessageType('UnsupportedApiMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _UNSUPPORTEDAPIMESSAGERESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.UnsupportedApiMessageResponse)
  ))
_sym_db.RegisterMessage(UnsupportedApiMessageResponse)

APIMessage = _reflection.GeneratedProtocolMessageType('APIMessage', (_message.Message,), dict(
  DESCRIPTOR = _APIMESSAGE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.APIMessage)
  ))
_sym_db.RegisterMessage(APIMessage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\026com.thoughtworks.gauge\252\002\016Gauge.Messages'))
# @@protoc_insertion_point(module_scope)
