# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lsp.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import getgauge.messages.messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='lsp.proto',
  package='gauge.messages',
  syntax='proto3',
  serialized_pb=_b('\n\tlsp.proto\x12\x0egauge.messages\x1a\x0emessages.proto\"\x07\n\x05\x45mpty2\xea\x06\n\nlspService\x12S\n\x0cGetStepNames\x12 .gauge.messages.StepNamesRequest\x1a!.gauge.messages.StepNamesResponse\x12\x44\n\tCacheFile\x12 .gauge.messages.CacheFileRequest\x1a\x15.gauge.messages.Empty\x12_\n\x10GetStepPositions\x12$.gauge.messages.StepPositionsRequest\x1a%.gauge.messages.StepPositionsResponse\x12_\n\x16GetImplementationFiles\x12\x15.gauge.messages.Empty\x1a..gauge.messages.ImplementationFileListResponse\x12X\n\rImplementStub\x12-.gauge.messages.StubImplementationCodeRequest\x1a\x18.gauge.messages.FileDiff\x12Y\n\x0cValidateStep\x12#.gauge.messages.StepValidateRequest\x1a$.gauge.messages.StepValidateResponse\x12M\n\x08Refactor\x12\x1f.gauge.messages.RefactorRequest\x1a .gauge.messages.RefactorResponse\x12P\n\x0bGetStepName\x12\x1f.gauge.messages.StepNameRequest\x1a .gauge.messages.StepNameResponse\x12_\n\x0fGetGlobPatterns\x12\x15.gauge.messages.Empty\x1a\x35.gauge.messages.ImplementationFileGlobPatternResponse\x12H\n\x0bKillProcess\x12\".gauge.messages.KillProcessRequest\x1a\x15.gauge.messages.EmptyB)\n\x16\x63om.thoughtworks.gauge\xaa\x02\x0eGauge.Messagesb\x06proto3')
  ,
  dependencies=[messages__pb2.DESCRIPTOR,])




_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='gauge.messages.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=52,
)

DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), dict(
  DESCRIPTOR = _EMPTY,
  __module__ = 'lsp_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.Empty)
  ))
_sym_db.RegisterMessage(Empty)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\026com.thoughtworks.gauge\252\002\016Gauge.Messages'))

_LSPSERVICE = _descriptor.ServiceDescriptor(
  name='lspService',
  full_name='gauge.messages.lspService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=55,
  serialized_end=929,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetStepNames',
    full_name='gauge.messages.lspService.GetStepNames',
    index=0,
    containing_service=None,
    input_type=messages__pb2._STEPNAMESREQUEST,
    output_type=messages__pb2._STEPNAMESRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CacheFile',
    full_name='gauge.messages.lspService.CacheFile',
    index=1,
    containing_service=None,
    input_type=messages__pb2._CACHEFILEREQUEST,
    output_type=_EMPTY,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetStepPositions',
    full_name='gauge.messages.lspService.GetStepPositions',
    index=2,
    containing_service=None,
    input_type=messages__pb2._STEPPOSITIONSREQUEST,
    output_type=messages__pb2._STEPPOSITIONSRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetImplementationFiles',
    full_name='gauge.messages.lspService.GetImplementationFiles',
    index=3,
    containing_service=None,
    input_type=_EMPTY,
    output_type=messages__pb2._IMPLEMENTATIONFILELISTRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ImplementStub',
    full_name='gauge.messages.lspService.ImplementStub',
    index=4,
    containing_service=None,
    input_type=messages__pb2._STUBIMPLEMENTATIONCODEREQUEST,
    output_type=messages__pb2._FILEDIFF,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateStep',
    full_name='gauge.messages.lspService.ValidateStep',
    index=5,
    containing_service=None,
    input_type=messages__pb2._STEPVALIDATEREQUEST,
    output_type=messages__pb2._STEPVALIDATERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Refactor',
    full_name='gauge.messages.lspService.Refactor',
    index=6,
    containing_service=None,
    input_type=messages__pb2._REFACTORREQUEST,
    output_type=messages__pb2._REFACTORRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetStepName',
    full_name='gauge.messages.lspService.GetStepName',
    index=7,
    containing_service=None,
    input_type=messages__pb2._STEPNAMEREQUEST,
    output_type=messages__pb2._STEPNAMERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetGlobPatterns',
    full_name='gauge.messages.lspService.GetGlobPatterns',
    index=8,
    containing_service=None,
    input_type=_EMPTY,
    output_type=messages__pb2._IMPLEMENTATIONFILEGLOBPATTERNRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='KillProcess',
    full_name='gauge.messages.lspService.KillProcess',
    index=9,
    containing_service=None,
    input_type=messages__pb2._KILLPROCESSREQUEST,
    output_type=_EMPTY,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_LSPSERVICE)

DESCRIPTOR.services_by_name['lspService'] = _LSPSERVICE

# @@protoc_insertion_point(module_scope)
